showCursor property

bool showCursor
final

Whether to show the cursor and text selection visuals (highlight and selection handles) in the fields.

Defaults to false: the focused field is indicated only by its focused border. The internal selection used so that typing replaces the focused digit is kept invisible instead.

Implementation

final bool showCursor;